@@ -154,3 +154,6 @@
 
 /* EJ added these */
 #undef NOISY_SHELL
+
+/* Define if you have a member ut_syslen in struct utmp or utmpx.  */
+#undef HAVE_UT_SYSLEN
