@@ -10,13 +10,17 @@
 #include <config.h>
 
 #include "rcsid.h"
-RCSID("$Id: xmalloc.c,v 1.1.1.1 1996/08/10 07:59:50 marekm Exp $")
+RCSID("$Id: xmalloc.c,v 1.1 2000/12/17 05:34:11 tom Exp $")
 
 #include <stdio.h>
 
 #include "defines.h"
 
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#else
 extern char *malloc();
+#endif /* HAVE_STDLIB_H */
 
 char *
 xmalloc(size)
