@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1999  The Stanford SRP Authentication Project
+ * Copyright (c) 1997-2001  The Stanford SRP Authentication Project
  * All Rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -26,20 +26,21 @@
  * In addition, the following conditions apply:
  *
  * 1. Any software that incorporates the SRP authentication technology
- *    must display the following acknowlegment:
+ *    is requested to display the following acknowlegment:
  *    "This product uses the 'Secure Remote Password' cryptographic
  *     authentication system developed by Tom Wu (tjw@CS.Stanford.EDU)."
  *
  * 2. Any software that incorporates all or part of the SRP distribution
- *    itself must also display the following acknowledgment:
+ *    itself must display the following acknowledgment:
  *    "This product includes software developed by Tom Wu and Eugene
- *     Jhong for the SRP Distribution (http://srp.stanford.edu/srp/)."
+ *     Jhong for the SRP Distribution (http://srp.stanford.edu/)."
  *
  * 3. Redistributions in source or binary form must retain an intact copy
  *    of this copyright notice and list of conditions.
  */
 
 #include <stdio.h>
+#include "config.h"
 
 #define FSEPARATOR	':'
 
